{ config, pkgs, ... }:

{
  boot = {
    supportedFilesystems = [ "zfs" ];
    zfs = {
      forceImportRoot = false;
    };
  };

  environment = {
    binsh = "${pkgs.dash}/bin/dash";
    shells = with pkgs; [
      bash
      dash
      zsh
    ];
    systemPackages = with pkgs; [
      borgbackup
      git
      gnupg
      jq
      mosh
      silver-searcher
      tmux
      vim
    ];
  };

  i18n = {
    defaultLocale = "en_US.UTF-8";
    supportedLocales = [
      "C.UTF-8/UTF-8"
      "en_US.UTF-8/UTF-8"
      "nl_NL.UTF-8/UTF-8"
    ];
  };

  networking = {
    domain = "tyil.net";
  };

  programs = {
    zsh = {
      enable = true;
    };
  };

  services = {
    openssh = {
      enable = true;
    };
  };

  system = {
    copySystemConfiguration = true;
  };

  time = {
    timeZone = "Europe/Amsterdam";
  };

  users = {
    users = {
      tyil = {
        extraGroups = [ "wheel" ];
        isNormalUser = true;
        shell = pkgs.zsh;
      };
    };
  };
}
